@@ -33,256 +33,261 @@ def _make_node(Name, Fields, Attributes, Bases):
                  {'__init__': create_node}))
 
 
-_nodes = {
+_nodes = (
     # mod
-    'Module': (('body', 'type_ignores'), (), (mod,)),
-    'Interactive': (('body',), (), (mod,)),
-    'Expression': (('body',), (), (mod,)),
-    'FunctionType': (('argtypes', 'returns'), (), (mod,)),
-    'Suite': (('body',), (), (mod,)),
+    ('Module', (('body', 'type_ignores'), (), (mod,))),
+    ('Interactive', (('body',), (), (mod,))),
+    ('Expression', (('body',), (), (mod,))),
+    ('FunctionType', (('argtypes', 'returns'), (), (mod,))),
+    ('Suite', (('body',), (), (mod,))),
 
     # stmt
-    'FunctionDef': (('name', 'args', 'body', 'decorator_list', 'returns',
-                     'type_comment'),
-                    ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                    (stmt,)),
-    'AsyncFunctionDef': (('name', 'args', 'body',
-                          'decorator_list', 'returns',
-                          'type_comment'),
-                         ('lineno', 'col_offset',
-                          'end_lineno', 'end_col_offset',),
-                         (stmt,)),
-    'ClassDef': (('name', 'bases', 'keywords', 'body', 'decorator_list',),
-                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (stmt,)),
-    'Return': (('value',),
-               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'Delete': (('targets',),
-               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'Assign': (('targets', 'value',),
-               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'AugAssign': (('target', 'op', 'value',),
+    ('FunctionDef', (('name', 'args', 'body', 'decorator_list', 'returns',
+                      'type_comment'),
+                     ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                     (stmt,))),
+    ('AsyncFunctionDef', (('name', 'args', 'body',
+                           'decorator_list', 'returns',
+                           'type_comment'),
+                          ('lineno', 'col_offset',
+                           'end_lineno', 'end_col_offset',),
+                          (stmt,))),
+    ('ClassDef', (('name', 'bases', 'keywords', 'body', 'decorator_list',),
                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (stmt,)),
-    'AnnAssign': (('target', 'annotation', 'value', 'simple',),
-                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (stmt,)),
-    'Print': (('dest', 'values', 'nl',),
-              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (stmt,)),
-    'For': (('target', 'iter', 'body', 'orelse', 'type_comment'),
-            ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-            (stmt,)),
-    'AsyncFor': (('target', 'iter', 'body', 'orelse', 'type_comment'),
-                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (stmt,)),
-    'While': (('test', 'body', 'orelse',),
-              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (stmt,)),
-    'If': (('test', 'body', 'orelse',),
-           ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-           (stmt,)),
-    'With': (('items', 'body', 'type_comment'),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (stmt,)),
-    'AsyncWith': (('items', 'body', 'type_comment'),
-                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (stmt,)),
-    'Raise': (('exc', 'cause',),
-              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (stmt,)),
-    'Try': (('body', 'handlers', 'orelse', 'finalbody',),
-            ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-            (stmt,)),
-    'Assert': (('test', 'msg',),
-               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'Import': (('names',),
-               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'ImportFrom': (('module', 'names', 'level',),
+                  (stmt,))),
+    ('Return', (('value',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('Delete', (('targets',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('Assign', (('targets', 'value',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('AugAssign', (('target', 'op', 'value',),
                    ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                   (stmt,)),
-    'Exec': (('body', 'globals', 'locals',),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (stmt,)),
-    'Global': (('names',),
+                   (stmt,))),
+    ('AnnAssign', (('target', 'annotation', 'value', 'simple',),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (stmt,))),
+    ('Print', (('dest', 'values', 'nl',),
                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (stmt,)),
-    'Nonlocal': (('names',),
-                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (stmt,)),
-    'Expr': (('value',),
+               (stmt,))),
+    ('For', (('target', 'iter', 'body', 'orelse', 'type_comment'),
              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (stmt,)),
-    'Pass': ((), ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (stmt,)),
-    'Break': ((), ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (stmt,)),
-    'Continue': ((), ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (stmt,)),
+             (stmt,))),
+    ('AsyncFor', (('target', 'iter', 'body', 'orelse', 'type_comment'),
+                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                  (stmt,))),
+    ('While', (('test', 'body', 'orelse',),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (stmt,))),
+    ('If', (('test', 'body', 'orelse',),
+            ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+            (stmt,))),
+    ('With', (('items', 'body', 'type_comment'),
+              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+              (stmt,))),
+    ('AsyncWith', (('items', 'body', 'type_comment'),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (stmt,))),
+    ('Raise', (('exc', 'cause',),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (stmt,))),
+    ('Try', (('body', 'handlers', 'orelse', 'finalbody',),
+             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+             (stmt,))),
+    ('Assert', (('test', 'msg',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('Import', (('names',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('ImportFrom', (('module', 'names', 'level',),
+                    ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                    (stmt,))),
+    ('Exec', (('body', 'globals', 'locals',),
+              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+              (stmt,))),
+    ('Global', (('names',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (stmt,))),
+    ('Nonlocal', (('names',),
+                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                  (stmt,))),
+    ('Expr', (('value',),
+              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+              (stmt,))),
+    ('Pass', ((), ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+              (stmt,))),
+    ('Break', ((), ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (stmt,))),
+    ('Continue', ((),
+                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                  (stmt,))),
 
     # expr
 
-    'BoolOp': (('op', 'values',),
+    ('BoolOp', (('op', 'values',),
+                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                (expr,))),
+    ('BinOp', (('left', 'op', 'right',),
                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (expr,)),
-    'BinOp': (('left', 'op', 'right',),
-              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (expr,)),
-    'UnaryOp': (('op', 'operand',),
+               (expr,))),
+    ('UnaryOp', (('op', 'operand',),
+                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                 (expr,))),
+    ('Lambda', (('args', 'body',),
                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                (expr,)),
-    'Lambda': (('args', 'body',),
+                (expr,))),
+    ('IfExp', (('test', 'body', 'orelse',),
                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-               (expr,)),
-    'IfExp': (('test', 'body', 'orelse',),
+               (expr,))),
+    ('Dict', (('keys', 'values',),
               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (expr,)),
-    'Dict': (('keys', 'values',),
+              (expr,))),
+    ('Set', (('elts',),
              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (expr,)),
-    'Set': (('elts',),
-            ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-            (expr,)),
-    'ListComp': (('elt', 'generators',),
+             (expr,))),
+    ('ListComp', (('elt', 'generators',),
+                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                  (expr,))),
+    ('SetComp', (('elt', 'generators',),
                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (expr,)),
-    'SetComp': (('elt', 'generators',),
-                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                (expr,)),
-    'DictComp': (('key', 'value', 'generators',),
+                 (expr,))),
+    ('DictComp', (('key', 'value', 'generators',),
+                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                  (expr,))),
+    ('GeneratorExp', (('elt', 'generators',),
+                      ('lineno', 'col_offset',
+                       'end_lineno', 'end_col_offset',),
+                      (expr,))),
+    ('Await', (('value',),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (expr,))),
+    ('Yield', (('value',),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (expr,))),
+    ('YieldFrom', (('value',),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (expr,))),
+    ('Compare', (('left', 'ops', 'comparators',),
                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (expr,)),
-    'GeneratorExp': (('elt', 'generators',),
-                     ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                     (expr,)),
-    'Await': (('value',),
+                 (expr,))),
+    ('Call', (('func', 'args', 'keywords',),
               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (expr,)),
-    'Yield': (('value',),
+              (expr,))),
+    ('Repr', (('value',),
               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (expr,)),
-    'YieldFrom': (('value',),
+              (expr,))),
+    ('FormattedValue', (('value', 'conversion', 'format_spec',),
+                        ('lineno', 'col_offset',
+                         'end_lineno', 'end_col_offset',),
+                        (expr,))),
+    ('JoinedStr', (('values',),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (expr,))),
+    ('Constant', (('value', 'kind'),
                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (expr,)),
-    'Compare': (('left', 'ops', 'comparators',),
-                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                (expr,)),
-    'Call': (('func', 'args', 'keywords',),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (expr,)),
-    'Repr': (('value',),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (expr,)),
-    'FormattedValue': (('value', 'conversion', 'format_spec',),
-                       ('lineno', 'col_offset',
-                        'end_lineno', 'end_col_offset',),
-                       (expr,)),
-    'JoinedStr': (('values',),
-                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (expr,)),
-    'Constant': (('value', 'kind'),
+                  (expr,))),
+    ('Attribute', (('value', 'attr', 'ctx',),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (expr,))),
+    ('Subscript', (('value', 'slice', 'ctx',),
+                   ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+                   (expr,))),
+    ('Starred', (('value', 'ctx',),
                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                 (expr,)),
-    'Attribute': (('value', 'attr', 'ctx',),
-                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (expr,)),
-    'Subscript': (('value', 'slice', 'ctx',),
-                  ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                  (expr,)),
-    'Starred': (('value', 'ctx',),
-                ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-                (expr,)),
-    'Name': (('id', 'ctx', 'annotation', 'type_comment'),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (expr,)),
-    'List': (('elts', 'ctx',),
-             ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-             (expr,)),
-    'Tuple': (('elts', 'ctx',),
+                 (expr,))),
+    ('Name', (('id', 'ctx', 'annotation', 'type_comment'),
               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
-              (expr,)),
+              (expr,))),
+    ('List', (('elts', 'ctx',),
+              ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+              (expr,))),
+    ('Tuple', (('elts', 'ctx',),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (expr,))),
 
     # expr_context
-    'Load': ((), (), (expr_context,)),
-    'Store': ((), (), (expr_context,)),
-    'Del': ((), (), (expr_context,)),
-    'AugLoad': ((), (), (expr_context,)),
-    'AugStore': ((), (), (expr_context,)),
-    'Param': ((), (), (expr_context,)),
+    ('Load', ((), (), (expr_context,))),
+    ('Store', ((), (), (expr_context,))),
+    ('Del', ((), (), (expr_context,))),
+    ('AugLoad', ((), (), (expr_context,))),
+    ('AugStore', ((), (), (expr_context,))),
+    ('Param', ((), (), (expr_context,))),
 
     # slice
-    'Slice': (('lower', 'upper', 'step'), (), (slice,)),
-    'ExtSlice': (('dims',), (), (slice,)),
-    'Index': (('value',), (), (slice,)),
+    ('Slice', (('lower', 'upper', 'step'),
+               ('lineno', 'col_offset', 'end_lineno', 'end_col_offset',),
+               (slice,))),
 
     # boolop
-    'And': ((), (), (boolop,)),
-    'Or': ((), (), (boolop,)),
+    ('And', ((), (), (boolop,))),
+    ('Or', ((), (), (boolop,))),
 
     # operator
-    'Add': ((), (), (operator,)),
-    'Sub': ((), (), (operator,)),
-    'Mult': ((), (), (operator,)),
-    'MatMult': ((), (), (operator,)),
-    'Div': ((), (), (operator,)),
-    'Mod': ((), (), (operator,)),
-    'Pow': ((), (), (operator,)),
-    'LShift': ((), (), (operator,)),
-    'RShift': ((), (), (operator,)),
-    'BitOr': ((), (), (operator,)),
-    'BitXor': ((), (), (operator,)),
-    'BitAnd': ((), (), (operator,)),
-    'FloorDiv': ((), (), (operator,)),
+    ('Add', ((), (), (operator,))),
+    ('Sub', ((), (), (operator,))),
+    ('Mult', ((), (), (operator,))),
+    ('MatMult', ((), (), (operator,))),
+    ('Div', ((), (), (operator,))),
+    ('Mod', ((), (), (operator,))),
+    ('Pow', ((), (), (operator,))),
+    ('LShift', ((), (), (operator,))),
+    ('RShift', ((), (), (operator,))),
+    ('BitOr', ((), (), (operator,))),
+    ('BitXor', ((), (), (operator,))),
+    ('BitAnd', ((), (), (operator,))),
+    ('FloorDiv', ((), (), (operator,))),
 
     # unaryop
-    'Invert': ((), (), (unaryop, AST,)),
-    'Not': ((), (), (unaryop, AST,)),
-    'UAdd': ((), (), (unaryop, AST,)),
-    'USub': ((), (), (unaryop, AST,)),
+    ('Invert', ((), (), (unaryop, AST,))),
+    ('Not', ((), (), (unaryop, AST,))),
+    ('UAdd', ((), (), (unaryop, AST,))),
+    ('USub', ((), (), (unaryop, AST,))),
 
     # cmpop
-    'Eq': ((), (), (cmpop,)),
-    'NotEq': ((), (), (cmpop,)),
-    'Lt': ((), (), (cmpop,)),
-    'LtE': ((), (), (cmpop,)),
-    'Gt': ((), (), (cmpop,)),
-    'GtE': ((), (), (cmpop,)),
-    'Is': ((), (), (cmpop,)),
-    'IsNot': ((), (), (cmpop,)),
-    'In': ((), (), (cmpop,)),
-    'NotIn': ((), (), (cmpop,)),
+    ('Eq', ((), (), (cmpop,))),
+    ('NotEq', ((), (), (cmpop,))),
+    ('Lt', ((), (), (cmpop,))),
+    ('LtE', ((), (), (cmpop,))),
+    ('Gt', ((), (), (cmpop,))),
+    ('GtE', ((), (), (cmpop,))),
+    ('Is', ((), (), (cmpop,))),
+    ('IsNot', ((), (), (cmpop,))),
+    ('In', ((), (), (cmpop,))),
+    ('NotIn', ((), (), (cmpop,))),
 
     # comprehension
-    'comprehension': (('target', 'iter', 'ifs', 'is_async'), (), (AST,)),
+    ('comprehension', (('target', 'iter', 'ifs', 'is_async'), (), (AST,))),
 
     # excepthandler
-    'ExceptHandler': (('type', 'name', 'body'),
-                      ('lineno', 'col_offset', 'end_lineno', 'end_col_offset'),
-                      (excepthandler,)),
+    ('ExceptHandler', (('type', 'name', 'body'),
+                       ('lineno', 'col_offset',
+                        'end_lineno', 'end_col_offset'),
+                       (excepthandler,))),
 
     # arguments
-    'arguments': (('args', 'posonlyargs', 'vararg', 'kwonlyargs',
-                   'kw_defaults', 'kwarg', 'defaults'), (), (AST,)),
+    ('arguments', (('args', 'posonlyargs', 'vararg', 'kwonlyargs',
+                    'kw_defaults', 'kwarg', 'defaults'), (), (AST,))),
 
     # keyword
-    'keyword': (('arg', 'value'), (), (AST,)),
+    ('keyword', (('arg', 'value'),
+                 ('lineno', 'col_offset', 'end_lineno', 'end_col_offset'),
+                 (AST,))),
 
     # alias
-    'alias': (('name', 'asname'), (), (AST,)),
+    ('alias', (('name', 'asname'), (), (AST,))),
 
     # withitem
-    'withitem': (('context_expr', 'optional_vars'), (), (AST,)),
+    ('withitem', (('context_expr', 'optional_vars'), (), (AST,))),
 
     # type_ignore
-    'type_ignore': ((), ('lineno', 'tag'), (TypeIgnore,)),
-}
+    ('type_ignore', ((), ('lineno', 'tag'), (TypeIgnore,))),
+    )
 
-for name, descr in _nodes.items():
+for name, descr in _nodes:
     _make_node(name, *descr)
 
 if _sys.version_info.major == 2:
@@ -371,7 +376,7 @@ def increment_lineno(node, n=1):
     """
     for child in walk(node):
         if 'lineno' in child._attributes:
-            child.lineno = getattr(child, 'lineno', 0) + n
+            child.lineno = (getattr(child, 'lineno', 0) or 0) + n
         if 'end_lineno' in child._attributes:
-            child.end_lineno = getattr(child, 'end_lineno', 0) + n
+            child.end_lineno = (getattr(child, 'end_lineno', 0) or 0) + n
     return node
